@@ -52,7 +52,8 @@ def setup(settings_path=None, **settings_patches):
                 # Build and install
                 local('python uwsgiconfig.py --build beanstalk')
                 local('cp uwsgi /usr/local/bin/uwsgi')
-                local('ln -s /usr/local/bin/uwsgi /usr/bin/wsgi')
+                if not os.path.exists('/usr/bin/uwsgi'):
+                    local('ln -s /usr/local/bin/uwsgi /usr/bin/uwsgi')
                 # mod_uwsgi
                 local('apxs -i -c apache2/mod_uwsgi.c')
                 local('echo "LoadModule uwsgi_module modules/mod_uwsgi.so" >> /etc/httpd/conf.d/uwsgi.conf')
